.. raw:: html

    <style> .red {color:#aa0060; font-weight:bold; font-size:18px} </style>

.. role:: red

.. This documentation was autogenerated using parselglossy. Editing by hand is not recommended.

================
Input parameters
================

- Keywords without a default value are **required**.
- Default values are either explicit or computed from the value of other keywords in the input.
- Sections where all keywords have a default value can be omitted.
- Predicates, if present, are the functions run to validate user input.

:red:`Keywords`
 :title: Title of the calculation.

  **Type** ``str``

:red:`Sections`
 :foo: brilliant

  :red:`Keywords`
   :tragic: Title of the calculation.
  
    **Type** ``str``
  
    **Default** ``Wham! Bang! Pow! Let's Rock Out!``
  
  :red:`Sections`
   :Bar: A ba-bar section
  
      :red:`Keywords`
       :amazing: Title of the calculation.
      
        **Type** ``str``
      
        **Default** ``Bobson Dugnutt``
      